@@ -1,6 +1,5 @@
 import os
-
-from typing import List, Dict, Union
+from typing import Dict, List, Union
 
 
 def get_value(possible_value: List[str], env_vars: Dict[str, str] = None, default: str = None):
