@@ -1,9 +1,8 @@
-from typing import List, Dict
+import os
+import sys
+from typing import Dict, List
 
 import gitlab
-import sys
-
-import os
 
 
 class GitlabCIVars:
@@ -11,10 +10,11 @@ class GitlabCIVars:
     Contient toutes les variable exposé lors d'un job Gitlab
     https://docs.gitlab.com/ee/ci/variables/predefined_variables.html
     """
-    
-    def __init__(self, environ: Dict[str, str]=None):
+
+    def __init__(self, environ: Dict[str, str] = None):
         self.environ = environ or dict(os.environ)
 
+    # region predefined variables
     @property
     def CHAT_CHANNEL(self):
         # 10.6 	all 	The Source chat channel that triggered the ChatOps command.return
@@ -550,6 +550,25 @@ class GitlabCIVars:
         # 13.9 	all 	The webhook payload. Only available when a pipeline is triggered with a webhook.
         return self.environ.get("TRIGGER_PAYLOAD", "")
 
+    # endregion
+    # region Predefined variables for merge request pipelines
+    @property
+    def CI_MERGE_REQUEST_EVENT_TYPE(self):
+        # 12.3  all     The event type of the merge request. Can be detached, merged_result or merge_train.
+        return self.environ.get("CI_MERGE_REQUEST_EVENT_TYPE", "")
+
+    @property
+    def CI_MERGE_REQUEST_TARGET_BRANCH_NAME(self):
+        # 11.6  all    The target branch name of the pull request.
+        return self.environ.get("CI_MERGE_REQUEST_TARGET_BRANCH_NAME", "")
+
+    @property
+    def CI_MERGE_REQUEST_TARGET_BRANCH_SHA(self):
+        # 11.9  all    The HEAD SHA of the target branch of the pull request.
+        return self.environ.get("CI_MERGE_REQUEST_TARGET_BRANCH_SHA", "")
+
+    # endregion
+
 
 GITLAB_CI_VARS = GitlabCIVars()
 
@@ -559,7 +578,6 @@ def log(*args):
 
 
 class BranchManager:
-
     @staticmethod
     def try_find_suitable_branch(project: "gitlab.v4.objects.projects.Project", branch_to_try_names: List[str]):
         for branch_name in branch_to_try_names:
@@ -575,7 +593,9 @@ class BranchManager:
         return project.default_branch
 
     @staticmethod
-    def convert_ODOO_DEPENDS_to_ADDONS_GIT(gitlab_api: gitlab.Gitlab, odoo_depends: str, env_vars: Dict[str, str], default_branch_to_try_names:List[str]) -> Dict[str, str]:
+    def convert_ODOO_DEPENDS_to_ADDONS_GIT(
+        gitlab_api: gitlab.Gitlab, odoo_depends: str, env_vars: Dict[str, str], default_branch_to_try_names: List[str]
+    ) -> Dict[str, str]:
         env = dict(env_vars)
         for project_name in odoo_depends.split(","):
             project = gitlab_api.projects.get(project_name)
@@ -588,7 +608,9 @@ class BranchManager:
         return env
 
     @staticmethod
-    def try_find_branch_for_ADDONS_GIT(gitlab_api: gitlab.Gitlab, env_vars: Dict[str, str], default_branch_to_try_names:List[str]) -> Dict[str, str]:
+    def try_find_branch_for_ADDONS_GIT(
+        gitlab_api: gitlab.Gitlab, env_vars: Dict[str, str], default_branch_to_try_names: List[str]
+    ) -> Dict[str, str]:
         env = dict(env_vars)
         for project_name in odoo_depends.split(","):
             project = gitlab_api.projects.get(project_name)
@@ -601,7 +623,7 @@ class BranchManager:
         return env
 
     @staticmethod
-    def convert_CI_VARS_to_ADDONS_GIT(vars:GitlabCIVars) -> Dict[str, str]:
+    def convert_CI_VARS_to_ADDONS_GIT(vars: GitlabCIVars) -> Dict[str, str]:
         return {
             f"ADDONS_GIT_{vars.CI_PROJECT_PATH.upper()}": vars.CI_PROJECT_PATH,
             f"ADDONS_GIT_{vars.CI_PROJECT_PATH.upper()}_BRANCH": vars.CI_COMMIT_REF_NAME,
@@ -609,4 +631,3 @@ class BranchManager:
             f"ADDONS_GIT_{vars.CI_PROJECT_PATH.upper()}_HTTPS_LOGIN": vars.CI_DEPLOY_USER,
             f"ADDONS_GIT_{vars.CI_PROJECT_PATH.upper()}_HTTPS_PASSWORD": vars.CI_DEPLOY_PASSWORD or vars.CI_JOB_TOKEN,
         }
-
